diff --git a/src/lib/oauthClientId.test.ts b/src/lib/oauthClientId.test.ts
index 84651d4..1c237a7 100644
--- a/src/lib/oauthClientId.test.ts
+++ b/src/lib/oauthClientId.test.ts
@@ -36,17 +36,17 @@ describe('getOAuthClientId', () => {
it('falls back to the built-in default when the placeholder is empty', async () => {
const getOAuthClientId = await loadWithMeta('');
- expect(getOAuthClientId()).toBe('stalwart-webui');
+ expect(getOAuthClientId()).toBe('inbuxa-webui');
});
it('falls back to the built-in default when the placeholder is only whitespace', async () => {
const getOAuthClientId = await loadWithMeta('');
- expect(getOAuthClientId()).toBe('stalwart-webui');
+ expect(getOAuthClientId()).toBe('inbuxa-webui');
});
it('falls back to the built-in default when the placeholder is absent', async () => {
const getOAuthClientId = await loadWithMeta('');
- expect(getOAuthClientId()).toBe('stalwart-webui');
+ expect(getOAuthClientId()).toBe('inbuxa-webui');
});
it('is inbuxa-admin when hosted apart from the server', async () => {
diff --git a/src/services/jmap/client.ts b/src/services/jmap/client.ts
index 42dba6d..1a5fd12 100644
--- a/src/services/jmap/client.ts
+++ b/src/services/jmap/client.ts
@@ -15,7 +15,7 @@ import type { Schema } from '@/types/schema';
const JMAP_USING = [
'urn:ietf:params:jmap:core',
- 'urn:stalwart:jmap',
+ 'urn:inbuxa:jmap:registry',
'urn:ietf:params:jmap:blob',
'urn:ietf:params:jmap:mail',
'urn:ietf:params:jmap:calendars',
diff --git a/src/lib/oauthClientId.ts b/src/lib/oauthClientId.ts
index e58c83a..5006b03 100644
--- a/src/lib/oauthClientId.ts
+++ b/src/lib/oauthClientId.ts
@@ -9,10 +9,10 @@
// INBUXA requires OAuth clients to be registered, and registers these two on
// every start (inbuxa-server contract C-6). Served by the server itself, this
// is the web interface at /admin, registered as `stalwart-webui`. Hosted
// anywhere else, with the server's address in , it
// is INBUXA Admin, registered as `inbuxa-admin` from INBUXA_ADMIN_URL.
-const SERVED_BY_SERVER_CLIENT_ID = 'stalwart-webui';
+const SERVED_BY_SERVER_CLIENT_ID = 'inbuxa-webui';
const HOSTED_ELSEWHERE_CLIENT_ID = 'inbuxa-admin';
let cached: string | undefined;
@@ -9,10 +9,10 @@
// INBUXA requires OAuth clients to be registered, and registers these two on
// every start (inbuxa-server contract C-6). Served by the server itself, this
-// is the web interface at /admin, registered as `stalwart-webui`. Hosted
+// is the web interface at /admin, registered as `inbuxa-webui`. Hosted
// anywhere else, with the server's address in , it
// is INBUXA Admin, registered as `inbuxa-admin` from INBUXA_ADMIN_URL.